@@ -8,56 +8,26 @@
 
 mod errors;
 
-use crate::{MessageId, MessageType, WireMsg};
+use crate::{MessageId, MessageType, SectionAuthorityProvider, WireMsg};
 use bytes::Bytes;
 pub use errors::Error;
 use serde::{Deserialize, Serialize};
-use sn_data_types::{PublicKey, ReplicaPublicKeySet};
-use std::{collections::BTreeMap, fmt, net::SocketAddr};
+use sn_data_types::PublicKey;
 use threshold_crypto::PublicKey as BlsPublicKey;
-use xor_name::{Prefix, XorName};
+use xor_name::XorName;
 
 /// Messages for exchanging network info, specifically on a target section for a msg.
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone)]
-pub enum Message {
-    /// Message to request information about the section that matches the given name.
-    GetSectionQuery {
-        public_key: PublicKey,
-        is_node: bool,
-    },
+pub enum SectionInfoMsg {
+    /// SectionInfoMsg to request information about the section that matches the given name.
+    GetSectionQuery(PublicKey),
     /// Response to `GetSectionQuery`.
     GetSectionResponse(GetSectionResponse),
     /// Updated info related to section
     SectionInfoUpdate(ErrorResponse),
 }
 
-/// All the info a client needs about their section
-#[derive(Serialize, Deserialize, Hash, PartialEq, PartialOrd, Ord, Eq, Clone)]
-pub struct SectionInfo {
-    /// Prefix of the section.
-    pub prefix: Prefix,
-    /// Public key set of the section.
-    pub pk_set: ReplicaPublicKeySet,
-    /// Section elders.
-    pub elders: BTreeMap<XorName, SocketAddr>,
-    /// Whether the section is allowed to taking new joining node.
-    pub joins_allowed: bool,
-}
-
-impl fmt::Debug for SectionInfo {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(
-            f,
-            "SectionInfo {{ prefix: {:?}, pk_set: PkSet {{ public_key: {:?} }}, elders: {:?}, joins_allowed: {:?}}}",
-            self.prefix,
-            self.pk_set.public_key(),
-            self.elders,
-            self.joins_allowed
-        )
-    }
-}
-
 // Infrastructure error wrapper to add correltion info for triggering message
 #[derive(Debug, Serialize, Deserialize, Hash, PartialEq, PartialOrd, Ord, Eq, Clone)]
 pub struct ErrorResponse {
@@ -72,17 +42,15 @@ pub struct ErrorResponse {
 pub enum GetSectionResponse {
     /// Successful response to `GetSectionQuery`. Contains information about the requested
     /// section.
-    Success(SectionInfo),
-    /// The requesting node is not externally reachable
-    NodeNotReachable,
+    Success(SectionAuthorityProvider),
     /// Response to `GetSectionQuery` containing addresses of nodes that are closer to the
     /// requested name than the recipient. The request should be repeated to these addresses.
-    Redirect(Vec<(XorName, SocketAddr)>),
+    Redirect(SectionAuthorityProvider),
     /// Request could not be fulfilled due to section constellation updates
     SectionInfoUpdate(Error),
 }
 
-impl Message {
+impl SectionInfoMsg {
     /// Convenience function to deserialize a 'Query' from bytes received over the wire.
     /// It returns an error if the bytes don't correspond to a network info query.
     pub fn from(bytes: Bytes) -> crate::Result<Self> {
